# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-04-16 14:38:22
:LastEditTime: 2020-12-25 10:58:28
:LastEditors: ChenXiaolei
:Description: 内容管理平台基础路由
"""

# 框架引用
from .handlers.system import *
from .handlers.monitor import *

def seven_studio_route():
    return [
        (r"/monitor", MonitorHandler),
        # 登陆、注销
        (r"/Core/GetGeetestCode", core.GeetestCodeHandler),
        (r"/power/loginPlatform", core.LoginPlatformHandler),
        (r"/power/logout", core.LogoutHandler),
        (r"/core/uploadfiles", core.UploadFilesHandler),
        # 用户、角色
        (r"/power/GetUserInfo", power.GetUserInfoHandler),
        (r"/power/FocusPassword", power.FocusPasswordHandler),
        (r"/power/FocusChangeUserPw", power.FocusChangeUserPwHandler),
        (r"/power/ChangeCurrUserPw", power.ChangeCurrUserPwHandler),
        (r"/Power/SaveUser", power.SaveUserHandler),
        (r"/Power/SaveCurrUser", power.SaveCurrUserHandler),
        (r"/Power/GetUserList", power.GetUserListHandler),
        (r"/Power/GetUserProductList", power.GetUserProductListHandler),
        (r"/Power/GetRoleList", power.GetRoleListHandler),
        (r"/Power/GetUserRoleList", power.GetUserRoleListHandler),
        (r"/Power/GetRoleUserList", power.GetRoleUserListHandler),
        (r"/Power/SaveRole", power.SaveRoleHandler),
        (r"/Power/RemoveRoleUser", power.RemoveRoleUserHandler),
        (r"/Power/DeleteRole", power.DeleteRoleHandler),
        (r"/Power/DeleteUser", power.DeleteUserHandler),
        (r"/Power/ModifyUserStatus", power.ModifyUserStatusHandler),
        (r"/Power/CopyUserRole", power.CopyUserRoleHandler),
        (r"/Power/RemoveUserAllRole", power.RemoveUserAllRoleHandler),
        (r"/Power/ResetUserPassword", power.ResetUserPasswordHandler),
        (r"/Power/ResetUserFaildLoginCount",
         power.ResetUserFaildLoginCountHandler),
        # 产品管理
        (r"/Power/GetProductList", product.GetProductListHandler),
        (r"/Power/GetAllProductList", product.GetAllProductListHandler),
        (r"/Power/SaveProduct", product.SaveProductHandler),
        (r"/Power/DeleteProduct", product.DeleteProductHandler),
        # 文件管理
        (r"/File/GetStoragePathList", file.GetStoragePathListHandler),
        (r"/File/GetResourceList", file.GetResourceListHandler),
        (r"/File/GetRestrictList", file.GetRestrictListHandler),
        (r"/File/GetWaterImageList", file.GetWaterImageListHandler),
        (r"/File/GetHistoryList", file.GetHistoryListHandler),
        (r"/File/GetResourceInfo", file.GetResourceInfoHandler),
        (r"/File/GetStoragePathData", file.GetStoragePathDataHandler),
        (r"/File/GetWaterImageData", file.GetWaterImageDataHandler),
        (r"/File/SaveStoragePath", file.SaveStoragePathHandler),
        (r"/File/DeleteStoragePath", file.DeleteStoragePathHandler),
        (r"/File/SaveResource", file.SaveResourceHandler),
        (r"/File/DeleteResource", file.DeleteResourceHandler),
        (r"/File/SaveRestrict", file.SaveRestrictHandler),
        (r"/File/DeleteRestrict", file.DeleteRestrictHandler),
        (r"/File/SaveWaterImage", file.SaveWaterImageHandler),
        (r"/File/DeleteWaterImage", file.DeleteWaterImageHandler),
        (r"/File/DeleteHistory", file.DeleteHistoryHandler),
        # 菜单
        (r"/power/PowerPlatformMenu", menu.PowerPlatformMenuHandler),
        (r"/Power/GetMenuCoteSelect", menu.MenuCoteSelectHandler),
        (r"/Power/GetMenuCoteList", menu.MenuCoteListHandler),
        (r"/Power/PowerMenuTree", menu.PowerMenuTreeHandler),
        (r"/Power/MenuPowerInfo", menu.MenuPowerInfoHandler),
        (r"/Power/MenuTree", menu.MenuTreeHandler),
        (r"/Power/SaveFastMenu", menu.AddFastMenuHandler),
        (r"/Power/DeleteMenu", menu.DeleteMenuHandler),
        (r"/Power/SaveMenu", menu.SaveMenuHandler),
        (r"/Power/SaveCopyMenu", menu.SaveCopyMenuHandler),
        (r"/Power/MoveMenu", menu.MoveMenuHandler),
        (r"/Power/SaveMenuCote", menu.SaveMenuCoteHandler),
        (r"/Power/DeleteMenuCote", menu.DeleteMenuCoteHandler),
        (r"/Power/SyncSql", menu.SyncSqlHandler),
        (r"/Power/InsertSql", menu.InsertSqlHandler),
        (r"/Power/UpdateSql", menu.UpdateSqlHandler),
        # 配置
        (r"/settings/base", settings.BaseSettingsHandler),
    ]




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class RoleInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(RoleInfoModel, self).__init__(RoleInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class RoleInfo:

    def __init__(self):
        super(RoleInfo, self).__init__()
        self.RoleID = ""  # 角色标识
        self.RoleName = ""  # 角色名称
        self.Summary = ""  # 简介
        self.ModifyDate = "1900-01-01 00:00:00"  # 修改时间
        self.ModifyUserID = ""  # 修改人
        self.ChiefUserID = ""  # 直属用户ID

    @classmethod
    def get_field_list(self):
        return ['RoleID', 'RoleName', 'Summary', 'ModifyDate', 'ModifyUserID', 'ChiefUserID']
        
    @classmethod
    def get_primary_key(self):
        return "RoleID"

    def __str__(self):
        return "cms_roleinfo_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-12-09 19:11:51
:LastEditTime: 2020-12-25 10:04:04
:LastEditors: ChenXiaolei
:Description: 
"""

from seven_studio.handlers.studio_base import *
from seven_studio.models.db_models.settings.settings_base_model import *


class BaseSettingsHandler(StudioBaseHandler):
    @login_filter(True)
    def post_async(self):
        """
        :description: 设置站点基础信息
        :return 基础信息
        :last_editors: ChenXiaolei
        """
        login_background = self.get_param("login_background")
        login_logo = self.get_param("login_logo")
        banner_logo = self.get_param("banner_logo")
        title = self.get_param("title")

        settings_base = SettingsBaseModel().get_entity("")

        if not settings_base:
            settings_base = SettingsBase()

        settings_base.login_background = login_background
        settings_base.login_logo = login_logo
        settings_base.banner_logo = banner_logo
        settings_base.title = title

        if settings_base.id > 0:
            SettingsBaseModel().update_entity(settings_base)
        else:
            SettingsBaseModel().add_entity(settings_base)

        return self.reponse_json_success(settings_base)

    def get_async(self):
        """
        :description: 获取站点基础信息
        :return 基础信息
        :last_editors: ChenXiaolei
        """
        settings_base = SettingsBaseModel().get_dict("")

        if not settings_base:
            return self.reponse_json_success(None)

        return self.reponse_json_success(settings_base)



# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-08-05 16:32:25
:LastEditTime: 2020-12-25 10:58:59
:LastEditors: ChenXiaolei
:Description: 监控处理
"""

from seven_framework.config import *
from seven_framework.redis import *
from seven_framework.web_tornado.base_handler.base_api_handler import *


class MonitorHandler(BaseApiHandler): 
    def get_async(self):
        """
        :description: 通用监控处理
        :last_editors: ChenXiaolei
        """
        config_monitor = app_config

        # 遍历配置,监控状态
        for key, value in config_monitor.items():
            if type(value) != dict:
                continue

            # Check MYSQL
            if key.find("db") > -1:
                try:
                    MySQLHelper(value).connection()
                except:
                    self.write(f"Mysql监控异常:{traceback.format_exc()}")
                    return
            # Check Redis
            elif key.find("redis") > -1:
                now_time = str(time.time)

                try:
                    monitor_key = f"framework_monitor_{config_monitor['run_port']}"

                    redis_client = RedisHelper.redis_init(config_dict=value)

                    redis_client.set(monitor_key, now_time)

                    if redis_client.get(monitor_key).decode() != now_time:
                        self.write("Reids监控异常,数据存在存取延迟")
                        return
                except:
                    self.write(f"Redis监控异常:{traceback.format_exc()}")
                    return

        self.write("ok")




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ProductInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(ProductInfoModel, self).__init__(ProductInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class ProductInfo:

    def __init__(self):
        super(ProductInfo, self).__init__()
        self.ProductID = 0  # 产品ID
        self.ProductName = ""  # 产品名称
        self.ProductSubName = ""  # 产品简称
        self.ManageUrl = ""  # 业务地址
        self.PowerUrl = ""  # 权限地址
        self.Summary = ""  # 说明
        self.ImageUrl = ""  # 图片地址
        self.SuperID = ""  # 超管ID
        self.FileContextKey = ""  # 文件上下文配置
        self.LogContextKey = ""  # 日志上下文配置
        self.PlugWorkContextKey = ""  # 作业上下文配置
        self.ManageContextKey = ""  # 权限上下文配置
        self.IsRelease = 0  # 是否发布
        self.IsBrank = 0  # 是否新页面打开

    @classmethod
    def get_field_list(self):
        return ['ProductID', 'ProductName', 'ProductSubName', 'ManageUrl', 'PowerUrl', 'Summary', 'ImageUrl', 'SuperID', 'FileContextKey', 'LogContextKey', 'PlugWorkContextKey', 'ManageContextKey', 'IsRelease', 'IsBrank']
        
    @classmethod
    def get_primary_key(self):
        return "ProductID"

    def __str__(self):
        return "cms_productinfo_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class SettingsBaseModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(SettingsBaseModel, self).__init__(SettingsBase, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class SettingsBase:

    def __init__(self):
        super(SettingsBase, self).__init__()
        self.id = 0  # 自增id
        self.login_background = ""  # 登录页背景图
        self.login_logo = ""  # 登录页logo
        self.banner_logo = ""  # 首页顶部logo
        self.title = ""  # 标题

    @classmethod
    def get_field_list(self):
        return ['id', 'login_background', 'login_logo', 'banner_logo', 'title']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cms_settings_base_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-12-09 19:10:46
:LastEditTime: 2020-12-10 11:08:48
:LastEditors: ChenXiaolei
:Description: 
"""
__all__=["file_restrict_model","file_water_image_model","file_storage_path_model","file_history_model","file_resource_model","file_restrict_pic_model",]



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class MenuInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(MenuInfoModel, self).__init__(MenuInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class MenuInfo:

    def __init__(self):
        super(MenuInfo, self).__init__()
        self.MenuID = ""  # 菜单标识
        self.MenuName = ""  # 菜单名称
        self.ParentID = ""  # 父标识
        self.IDPath = ""  # ID路经
        self.MenuNamePath = ""  # 菜单路径
        self.Depth = 0  # 深度
        self.HaveChild = 0  # 是否有子结点
        self.SortIndex = 0  # 排序
        self.ApiPath = ""  # 接口地址
        self.ViewPath = ""  # 视图地址
        self.TargetUrl = ""  # 跳转地址
        self.IsShow = 0  # 是否显示0不显示1显示
        self.IsPower = 0  # 是否授权0不1是
        self.MenuIcon = ""  # 图标地址
        self.ButtonType = 0  # 按钮类型0无1新增2修改3删除4保存5返回6查询7查看
        self.ButtonPlace = 0  # 1顶部2列表3底部
        self.CommandName = ""  # 菜单命令
        self.CommandParms = ""  # 菜单参数
        self.MenuType = 0  # 菜单类型
        self.ShowCondition = ""  # 菜单显示条件
        self.ButtonColor = ""  # 按钮颜色
        self.MenuCoteID = 0  # 栏目数据ID
        self.MenuCoteKey = ""  # 栏目标识

    @classmethod
    def get_field_list(self):
        return ['MenuID', 'MenuName', 'ParentID', 'IDPath', 'MenuNamePath', 'Depth', 'HaveChild', 'SortIndex', 'ApiPath', 'ViewPath', 'TargetUrl', 'IsShow', 'IsPower', 'MenuIcon', 'ButtonType', 'ButtonPlace', 'CommandName', 'CommandParms', 'MenuType', 'ShowCondition', 'ButtonColor', 'MenuCoteID', 'MenuCoteKey']
        
    @classmethod
    def get_primary_key(self):
        return "MenuID"

    def __str__(self):
        return "cms_menuinfo_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileResourceModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileResourceModel, self).__init__(FileResource, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileResource:

    def __init__(self):
        super(FileResource, self).__init__()
        self.FileResourceID = ""  # 文件资源标识
        self.FileResourceName = ""  # 文件资源名称
        self.FileResourceCode = ""  # 文件资源代码
        self.CreateDate = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['FileResourceID', 'FileResourceName', 'FileResourceCode', 'CreateDate']
        
    @classmethod
    def get_primary_key(self):
        return "FileResourceID"

    def __str__(self):
        return "cms_fileresource_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class UserInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(UserInfoModel, self).__init__(UserInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class UserInfo:

    def __init__(self):
        super(UserInfo, self).__init__()
        self.UserID = ""  # 用户ID
        self.IsSuper = 0  # 是否超管
        self.Account = ""  # 账号
        self.Password = ""  # 密码
        self.Email = ""  # 邮箱
        self.LoginIP = ""  # 登录IP
        self.PasswordQuestion = ""  # 密码问题
        self.PasswordAnswer = ""  # 密码答案
        self.IsLock = 0  # 是否被锁定
        self.CreateDate = "1900-01-01 00:00:00"  # 创建时间
        self.FaildLoginCount = 0  # 登录失败尝试次数
        self.FaildQuestionCount = 0  # 回答问题尝试次数
        self.UserName = ""  # 用户姓名
        self.NickName = ""  # 昵称
        self.JobNo = ""  # 工号
        self.Avatar = ""  # 头像
        self.LoginDate = "1900-01-01 00:00:00"  # 登录时间
        self.Phone = ""  # 手机号码
        self.PersonalitySignature = ""  # 个性签名
        self.UserIDNumber = 0  # 
        self.ChiefUserID = ""  # 直属用户ID

    @classmethod
    def get_field_list(self):
        return ['UserID', 'IsSuper', 'Account', 'Password', 'Email', 'LoginIP', 'PasswordQuestion', 'PasswordAnswer', 'IsLock', 'CreateDate', 'FaildLoginCount', 'FaildQuestionCount', 'UserName', 'NickName', 'JobNo', 'Avatar', 'LoginDate', 'Phone', 'PersonalitySignature', 'UserIDNumber', 'ChiefUserID']
        
    @classmethod
    def get_primary_key(self):
        return "UserID"

    def __str__(self):
        return "cms_userinfo_tb"
    


"""
:Author: HuangJingCan
:Date: 2020-03-24 19:48:05
:LastEditTime: 2020-12-25 10:04:18
:LastEditors: ChenXiaolei
:Description: 
"""
from seven_studio.handlers.studio_base import *
from seven_studio.libs.geetest import *

from seven_studio.models.db_models.user.user_info_model_ex import *
from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.user.user_login_model import *
from seven_studio.models.seven_model import InvokeResult
from seven_studio.libs.file.upload import *


class CoreHandler(StudioBaseHandler):
    def get_async(self):
        result = "后台接口站"
        self.write(result)


class GeetestCodeHandler(StudioBaseHandler):
    """
    :description: 获取极验证的验证码
    """
    def get_async(self):
        user_id = 'test'
        gt = GeetestLib(config.get_value("pc_geetest_id"), config.get_value("pc_geetest_key"))
        status = gt.pre_process(user_id, JSON_FORMAT=0, ip_address="127.0.0.1")
        if not status:
            status = 2
        response_str = gt.get_response_str()

        self.reponse_json_success(response_str)


class LoginPlatformHandler(StudioBaseHandler):
    """
    :description: 登陆
    """
    def get_async(self):
        account = self.get_param("account")
        password = self.get_param("password")
        challenge = self.get_param("challenge")
        validate = self.get_param("validate")
        seccode = self.get_param("seccode")

        if account == "":
            return self.reponse_common("EmptyAccount", "对不起，请你输入账号")

        if password == "":
            return self.reponse_common("EmptyPassword", "对不起，请您输入密码")

        if config.get_value("is_captcha_check"):
            if challenge == "" or validate == "" or seccode == "":
                return self.reponse_common("CaptchaError", "对不起，请先校验验证码")

            result = self.check_code(challenge, validate, seccode)
            if not result:
                return self.reponse_common("CaptchaError", "对不起，验证码验证失败")

        self.reponse_custom(self.login(account, password, True))

    def check_code(self, challenge="", validate="", seccode=""):
        """
        :description: 验证码校验
        :param challenge：challenge
        :param validate：validate
        :param seccode：seccode
        :return: true or false
        :last_editors: HuangJingCan
        """
        gt = GeetestLib(config.get_value("pc_geetest_id"), config.get_value("pc_geetest_key"))
        result = gt.success_validate(challenge, validate, seccode, JSON_FORMAT=0)
        return result == 1

    def login(self, account="", password="", is_platform=False):
        """
        :description: 登录验证
        :param account：账号
        :param password：密码
        :param is_platform：是否平台用户
        :return: invoke_result
        :last_editors: HuangJingCan
        """
        manage_context_key = config.get_value("manage_context_key")
        base_manage_context_key = config.get_value("base_manage_context_key")
        invoke_result = InvokeResult()
        user_info_model = UserInfoModel(base_manage_context_key)
        user_info = user_info_model.get_entity("Account=%s", params=account)
        if not user_info:
            invoke_result.ResultCode = "NoExistAccount"
            invoke_result.ResultMessage = "账号不存在"
            return invoke_result

        if user_info.FaildLoginCount > 4:
            invoke_result.ResultCode = "FaildLoginCountLimit"
            invoke_result.ResultMessage = "密码输入错误限制，请联系管理员解除限制"
            return invoke_result

        verify_password = UserInfoModelEx().verify_password(password, user_info.Password, user_info.UserID)
        if not verify_password:
            user_info.FaildLoginCount += 1
            user_info_model.update_table("FaildLoginCount=%s", "UserID=%s", [user_info.FaildLoginCount, user_info.UserID])
            invoke_result.ResultCode = "ErrorPassword"
            invoke_result.ResultMessage = "密码错误，尝试次数" + str(user_info.FaildLoginCount)
            return invoke_result

        if user_info.IsLock == 1:
            invoke_result.ResultCode = "AccountLock"
            invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
            return invoke_result

        is_super = user_info.IsSuper == 1

        if manage_context_key != base_manage_context_key:
            user_info_model_part = UserInfoModel(manage_context_key)
            user_info_curr = user_info_model_part.get_entity("Account=%s", params=account)
            if not user_info_curr:
                invoke_result.ResultCode = "NoExistAccount"
                invoke_result.ResultMessage = "账号不存在"
                return invoke_result
            if user_info_curr.IsLock == 1:
                invoke_result.ResultCode = "AccountLock"
                invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
                return invoke_result

            is_super = user_info_curr.IsSuper == 1 or user_info.IsSuper == 1

        if is_platform and not is_super:
            role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=user_info.UserID)
            if len(role_user_list) == 0:
                invoke_result.ResultCode = "AccountLock"
                invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
                return invoke_result

            role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
            if not [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform")]:
                invoke_result.ResultCode = "AccountLock"
                invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
                return invoke_result

        user_info.FaildLoginCount = 0
        user_info.LoginDate = TimeHelper.get_now_datetime()
        user_info.LoginIP = self.get_remote_ip()
        user_info_model.update_table("FaildLoginCount=%s,LoginDate=%s,LoginIP=%s", "UserID=%s", [user_info.FaildLoginCount, user_info.LoginDate, user_info.LoginIP, user_info.UserID])

        invoke_result.ResultCode = "0"
        invoke_result.ResultMessage = "调用成功"
        invoke_result.Data = self.set_user_info_login_status(user_info).__dict__

        return invoke_result

    def set_user_info_login_status(self, user_info):
        """
        :description: 登录状态设置
        :param user_info：当前登录用户信息
        :return: user_login
        :last_editors: HuangJingCan
        """
        user_login = UserLogin()
        user_login.UserID = user_info.UserID
        user_login.UserIDMD5 = CryptoHelper.md5_encrypt(user_info.UserID, config.get_value("login_encrypt_key"))
        user_login.UserToken = UUIDHelper.get_uuid()
        user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))

        if config.get_value("login_type") == "redis":
            self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_login.UserID, self.json_dumps(user_login))
        else:
            user_login_base = UserLoginModel(config.get_value("base_manage_context_key"))
            user_login_base.add_update_entity(user_login, "UserIDMD5=%s,ExpireTime=%s,UserToken=%s", [user_login.UserIDMD5, user_login.ExpireTime, user_login.UserToken])

        # self.set_secure_cookie(name="UserID", value=user_login.UserID,domain=".gao7.com")
        # self.set_secure_cookie(name="UserIDMD5", value=user_login.UserIDMD5, domain=".gao7.com")
        # self.set_secure_cookie(name="UserToken", value=user_login.UserToken, domain=".gao7.com")
        self.set_secure_cookie("UserID", user_login.UserID)
        self.set_secure_cookie("UserIDMD5", user_login.UserIDMD5)
        self.set_secure_cookie("UserToken", user_login.UserToken)

        return user_login


class LogoutHandler(StudioBaseHandler):
    """
    :description: 注销
    """
    def post_async(self):
        """
        :description: 注销用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        self.logout(self.request_user_id())

        self.reponse_json_success()


class UploadFilesHandler(StudioBaseHandler):
    """
    :description: 上传图片
    """
    def post_async(self):
        """
        :description: 上传图片
        :param resourceCode：resourceCode
        :param resourceCode：restrictCode
        :return: json
        :last_editors: HuangJingCan
        """
        # 获取参数
        resource_code = self.get_param("resourceCode")
        restrict_code = self.get_param("restrictCode")

        # 验证数据
        if resource_code == "":
            return self.reponse_common("ResourceCodeEmpty", "资源代码不能为空")
        if restrict_code == "":
            return self.reponse_common("RestrictCodeEmpty", "资源限制码不能为空")

        invoke_result = FileUpload(self.get_file_context_key()).upload(resource_code, restrict_code, self.request.files)

        if invoke_result.ResultCode == "0":
            self.reponse_json_success(invoke_result.Data)
        else:
            self.reponse_custom(invoke_result)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileWaterImageModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileWaterImageModel, self).__init__(FileWaterImage, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileWaterImage:

    def __init__(self):
        super(FileWaterImage, self).__init__()
        self.WaterImageID = ""  # 
        self.WaterImagePath = ""  # 水印地址
        self.WaterName = ""  # 水印名称

    @classmethod
    def get_field_list(self):
        return ['WaterImageID', 'WaterImagePath', 'WaterName']
        
    @classmethod
    def get_primary_key(self):
        return "WaterImageID"

    def __str__(self):
        return "cms_filewaterimage_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ProductUserModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(ProductUserModel, self).__init__(ProductUser, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class ProductUser:

    def __init__(self):
        super(ProductUser, self).__init__()
        self.ProductUserID = 0  # ProductUserID
        self.ProductID = 0  # 产品ID
        self.UserID = ""  # 用户ID

    @classmethod
    def get_field_list(self):
        return ['ProductUserID', 'ProductID', 'UserID']
        
    @classmethod
    def get_primary_key(self):
        return "ProductUserID"

    def __str__(self):
        return "cms_productuser_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileHistoryModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileHistoryModel, self).__init__(FileHistory, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileHistory:

    def __init__(self):
        super(FileHistory, self).__init__()
        self.FileHistoryID = 0  # 文件上传历史记录
        self.FileResourceID = ""  # 文件资源标识
        self.FileRestrictID = ""  # 限制码标识
        self.FileStoragePathID = ""  # 存储标识
        self.FileType = 0  # 1文件2图片3flash4mid
        self.FileTitle = ""  # 文件标题
        self.FileUrl = ""  # 文件路经
        self.FileStatus = 0  # 状态1正常
        self.CreateDate = "1900-01-01 00:00:00"  # 创建时间
        self.CreateUserID = 0  # 上传用户标识

    @classmethod
    def get_field_list(self):
        return ['FileHistoryID', 'FileResourceID', 'FileRestrictID', 'FileStoragePathID', 'FileType', 'FileTitle', 'FileUrl', 'FileStatus', 'CreateDate', 'CreateUserID']
        
    @classmethod
    def get_primary_key(self):
        return "FileHistoryID"

    def __str__(self):
        return "cms_filehistory_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-04-29 10:02:31
:LastEditTime: 2021-01-04 19:34:36
:LastEditors: ChenXiaolei
:Description: 腾讯云存储
"""
import base64
from enum import Enum
from seven_framework.log import *
from seven_framework.uuid import *
from seven_framework.file import COSHelper

from seven_studio.utils.random import *

from seven_studio.models.seven_model import InvokeResult
from seven_studio.models.seven_model import FileUploadInfo


class COS:
    """
    :description: 腾讯云COS
    :last_editors: ChenXiaolei
    """
    logger_error = Logger.get_logger_by_name("log_error")
    logger_info = Logger.get_logger_by_name("log_info")

    @classmethod
    def upload(self, storage_config, file_name='', stream=None, file_path=''):
        """
        :description: 文件上传
        :param storage_config：配置内容
        :param file_name：文件名(按路径上传时此参数为空)
        :param stream：文件内容(按路径上传时此参数为空)
        :param file_path：文件路径(为空按stream上传，不为空则按路径上传)
        :return: InvokeResult
        :last_editors: ChenXiaolei
        """

        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        domain = file_upload_config.get("Domain", "").rstrip('/')
        is_autofile_name = file_upload_config.get("IsAutoFileName", 0)
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(
            file_path) if file_path != "" else file_name

        if is_autofile_name == 1:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension

        try:
            conn = COSHelper(access_key, secret_key, end_point)
            key_name = folder + file_name
            result = False
            if file_path != "":
                result = conn.put_file_from_file_path(bucket, key_name,
                                                      file_path)
            else:
                result = conn.put_file(bucket, key_name, stream)

            if result:
                virtual_name = RandomUtil.get_random_switch_string(
                    domain).rstrip('/')
                file_upload_info.ResourcePath = virtual_name + "/" + key_name
                invoke_result.Data = file_upload_info.__dict__
        except Exception as ex:
            self.logger_error.exception(ex)
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = "OSS上传文件出错"

        return invoke_result

    @classmethod
    def delete(self, storage_config, file_path):
        """
        :description: 删除文件
        :param storage_config：配置内容
        :param file_path：文件路径
        :return: 成功返回1 失败0
        :last_editors: ChenXiaolei
        """

        if file_path == "":
            return 1
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(file_path) if file_path != "" else ""

        result = 0

        try:
            conn = COSHelper(access_key, secret_key, end_point)
            conn.del_file(bucket, folder + file_name)
            result = 1
        except Exception as ex:
            self.logger_error.exception(ex)

        return result

    @classmethod
    def get(self, storage_config, file_path):
        """
        :description: 获取文件
        :param storage_config：配置内容
        :param file_path：文件路径或者文件名
        :return: 文件流
        :last_editors: ChenXiaolei
        """
        invoke_result = InvokeResult()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(file_path) if file_path != "" else ""

        result = ""

        try:
            conn = COSHelper(access_key, secret_key, end_point)
            result = conn.get_file_contents(bucket, folder + file_name)
        except Exception as ex:
            self.logger_error.exception(ex)

        return result

    @classmethod
    def get_list(self, storage_config, prefix=""):
        """
        :description: 列举Bucket内的文件或者目录
        :param storage_config：配置内容
        :param file_path：文件路径
        :param prefix：指定前缀
        :return: 文件列表，目录列表
        :last_editors: ChenXiaolei
        """
        invoke_result = InvokeResult()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        result_list = []
        result_dir = []

        try:
            conn = COSHelper(access_key, secret_key, end_point)
            result_list, result_dir = conn.get_bucket_objects(bucket, prefix)
        except Exception as ex:
            self.logger_error.exception(ex)

        return result_list, result_dir

    @classmethod
    def upload_part(self, storage_config, source_path):
        """
        :description: 分块上传-单线程
        :param storage_config：配置内容
        :param source_path：文件路径
        :param prefix：指定前缀
        :return: 文件列表，目录列表
        :last_editors: ChenXiaolei
        """
        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        domain = file_upload_config.get("Domain", "").rstrip('/')
        is_autofile_name = file_upload_config.get("IsAutoFileName", 0)
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        file_name = ""
        # 返回文件名
        file_name = os.path.basename(
            source_path) if source_path != "" else file_name

        if is_autofile_name == 1:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension

        try:
            conn = COSHelper(access_key, secret_key, end_point)
            conn.multi_put_file(bucket, folder + file_name, source_path)

            virtual_name = RandomUtil.get_random_switch_string(domain).rstrip(
                '/')
            file_upload_info.ResourcePath = virtual_name + "/" + folder + file_name
            invoke_result.Data = file_upload_info.__dict__

        except Exception as ex:
            self.logger_error.exception(ex)
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = "COS上传文件出错"

        return invoke_result

    @classmethod
    def water_marker_text(self,
                          img_url,
                          text,
                          font="",
                          fontsize="",
                          fill="",
                          dissolve="",
                          gravity="",
                          dx="",
                          dy="",
                          q=""):
        pass

    @classmethod
    def water_marker_img(self,
                         img_url,
                         image,
                         wtw="",
                         wth="",
                         dissolve="",
                         gravity="",
                         dx="",
                         dy="",
                         q=""):
        pass

    @classmethod
    def img_scale(self,
                  img_url,
                  w="",
                  h="",
                  m="",
                  p="",
                  so="",
                  q="",
                  F="",
                  r="",
                  c="",
                  f="",
                  s="",
                  cox="",
                  coy="",
                  rotate="",
                  et="",
                  etw="",
                  eth="",
                  etc=""):
        pass


"""
:Author: ChenXiaolei
:Date: 2020-03-24 10:42:34
:LastEditTime: 2020-12-25 10:04:58
:LastEditors: ChenXiaolei
:Description: StudioBaseHandler
"""

from seven_framework.web_tornado.base_handler.base_cookie_handler import *
from seven_framework.redis import *

from seven_studio.models.db_models.product.product_info_model import *
from seven_studio.models.db_models.user.user_login_model import *
from seven_studio.models.db_models.user.user_info_model import *
from seven_studio.models.db_models.menu.menu_info_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.seven_model import PageInfo
from seven_studio.models.enum import *


class StudioBaseHandler(BaseCookieHandler):
    """
    :description: StudioBaseHandler
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def options_async(self):
        self.reponse_json_success()

    def check_xsrf_cookie(self):
        return

    def json_dumps(self, rep_dic):
        """
        :description: 用于将字典形式的数据转化为字符串
        :param rep_dic：字典对象
        :return: str
        :last_editors: HuangJingCan
        """
        if hasattr(rep_dic, '__dict__'):
            rep_dic = rep_dic.__dict__
        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder)

    def reponse_custom(self, rep_dic):
        """
        :description: 输出公共json模型
        :param rep_dic: 字典类型数据
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.http_reponse(self.json_dumps(rep_dic))

    def reponse_common(self, result_code, result_message, data=None):
        """
        :description: 输出公共json模型
        :param result_code: 字符串，服务端返回的错误码
        :param result_message: 字符串，服务端返回的错误信息
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__
        rep_dic = {}
        rep_dic['ResultCode'] = result_code
        rep_dic['ResultMessage'] = result_message
        rep_dic['Data'] = data

        self.http_reponse(self.json_dumps(rep_dic))

    def reponse_json_success(self, data=None, desc='调用成功'):
        """
        :description: 通用成功返回json结构
        :param data: 返回结果对象，即为数组，字典
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.reponse_common("0", desc, data)

    def reponse_json_error(self, desc='error'):
        """
        :description: 通用错误返回json结构
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.reponse_common("1", desc)

    def reponse_json_error_params(self, desc='params error'):
        """
        :description: 参数错误返回json结构
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.reponse_common("1", desc)

    def redis_init(self, db=None):
        """
        :description: redis初始化
        :return: redis_cli
        :last_editors: HuangJingCan
        """
        host = config.get_value("redis")["host"]
        port = config.get_value("redis")["port"]
        if not db:
            db = config.get_value("redis")["db"]
        password = config.get_value("redis")["password"]
        redis_cli = RedisHelper.redis_init(host, port, db, password)
        return redis_cli

    def set_default_headers(self):
        allow_origin_list = config.get_value("allow_origin_list")
        origin = self.request.headers.get("Origin")
        if origin in allow_origin_list:
            self.set_header("Access-Control-Allow-Origin", origin)

        self.set_header(
            "Access-Control-Allow-Headers",
            "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID"
        )
        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
        self.set_header("Access-Control-Allow-Credentials", "true")

    def request_header_token(self):
        header_token = {}
        if "User-Token" in self.request.headers:
            reqInfoList = str.split(self.request.headers["User-Token"], ";")
            for info in reqInfoList:
                kv = str.split(info, "=")
                header_token[kv[0]] = kv[1]
        return header_token

    def request_user_id(self):
        header_token = self.request_header_token()
        if not header_token.__contains__("UserID"):
            return ""
        return header_token["UserID"]

    def request_user_id_md5(self):
        header_token = self.request_header_token()
        if not header_token.__contains__("UserIDMD5"):
            return ""
        return header_token["UserIDMD5"]

    def request_user_token(self):
        header_token = self.request_header_token()
        if not header_token.__contains__("UserToken"):
            return ""
        return header_token["UserToken"]

    def request_product_id(self):
        header_product_id = ""
        if self.request.headers.__contains__("Manage-Productid"):
            header_product_id = self.request.headers["Manage-Productid"]
        product_id = int(
            header_product_id) if header_product_id.strip() != "" else 0
        if product_id == 0:
            product_id = int(self.get_param("manage-productid", "0"))
        return product_id

    def request_manage_page_id(self):
        if not self.request.headers.__contains__("Manage-PageID"):
            return ""
        return self.request.headers["Manage-PageID"]

    def get_product_info(self):
        product_info = None
        product_id = self.request_product_id()
        if product_id > 0:
            product_info = ProductInfoModel(
                config.get_value("base_manage_context_key")).get_entity_by_id(
                    product_id)
        return product_info

    def get_curr_user_info(self):
        user_info = None
        user_id = self.request_user_id()
        if user_id:
            user_info = UserInfoModel(
                self.get_manage_context_key()).get_entity_by_id(user_id)
        return user_info

    def get_base_user_info(self):
        user_info = None
        user_id = self.request_user_id()
        if user_id:
            user_info = UserInfoModel(
                config.get_value("base_manage_context_key")).get_entity_by_id(
                    user_id)
        return user_info

    def get_is_super(self):
        base_user_info = self.get_base_user_info()
        is_super = False
        if base_user_info:
            is_super = True if base_user_info.IsSuper == 1 else False
        return is_super

    def get_manage_context_key(self):
        manage_context_key = config.get_value("manage_context_key")
        product_info = self.get_product_info()
        if product_info:
            manage_context_key = product_info.ManageContextKey
        return manage_context_key

    def get_file_context_key(self):
        file_context_key = config.get_value("file_context_key")
        product_info = self.get_product_info()
        if product_info:
            file_context_key = product_info.FileContextKey
        return file_context_key

    def get_log_context_key(self):
        log_context_key = config.get_value("log_context_key")
        product_info = self.get_product_info()
        if product_info:
            log_context_key = product_info.LogContextKey
        return log_context_key

    def get_page_index(self):
        page_index = 0
        r_page_index = self.get_param("PageIndex", "")
        if not r_page_index == "":
            dict_page_index = json.loads(r_page_index)
            if dict_page_index and dict_page_index.__contains__("Value"):
                page_index = dict_page_index["Value"]
        return page_index

    def get_page_size(self):
        page_size = 10
        r_page_size = self.get_param("PageSize", "")
        if not r_page_size == "":
            dict_page_size = json.loads(r_page_size)
            if dict_page_size and dict_page_size.__contains__("Value"):
                page_size = dict_page_size["Value"]
        return page_size

    def get_page_cote_id(self):
        page_cote_id = ""
        page_id = self.request_manage_page_id()
        if not page_id == "":
            page_cote_id = page_id.split("$")[1] if page_id.__contains__(
                "$") else ""
        return page_cote_id

    def get_dict_page_info_list(self, page_index, page_size, p_dict, total=0):
        """
        :description: 获取分页信息
        :param page_index：页索引
        :param page_size：页大小
        :param p_dict：字典列表
        :return: 
        :last_editors: HuangJingCan
        """
        page_info = PageInfo()
        page_info.PageIndex = page_index
        page_info.PageSize = page_size
        page_info.RecordCount = total if total>0 else len(p_dict)
        page_info.Data = p_dict
        page_info = page_info.get_entity_by_page_info(page_info)
        return page_info.__dict__

    def get_dict_by_keys(self, source_dict, keys):
        """
        :description: 根据key搜索字典，返回key相关字典
        :param source_dict
        :param keys
        :return: 值
        :last_editors: HuangJingCan
        """
        if isinstance(source_dict, str):
            source_dict = json.loads(source_dict)
        result = {}
        key_list = list(keys.split(","))
        for i in key_list:
            if i in source_dict:
                result[i] = source_dict[i]
        return result

    def get_condition_by_body(self):
        """
        :description: 获取页面查询条件
        :param {type} 
        :return: condition, order
        :last_editors: HuangJingCan
        """
        condition = ""
        order = ""
        body_dict = self.request_body_to_dict()
        for item in body_dict:
            if not item.__contains__("PageIndex") and not item.__contains__(
                    "PageSize"):
                # print(body_dict[item])
                query_method = json.loads(body_dict[item]).get("QueryMethod")
                query_Value = json.loads(body_dict[item]).get("Value")
                query_type = json.loads(body_dict[item]).get("QueryType")
                # query_data_type = json.loads(body_dict[item]).get("QueryDataType")
                if query_type == "Query" and query_Value != "":
                    if condition != "":
                        condition += " AND "
                    if query_method == QueryMethod.Contains.value:
                        condition += f"{item} LIKE '%{query_Value}%'"
                    elif query_method == QueryMethod.StartsWith.value:
                        condition += f"{item} LIKE '{query_Value}%'"
                    elif query_method == QueryMethod.EndsWith.value:
                        condition += f"{item} LIKE '%{query_Value}'"
                    elif query_method == QueryMethod.Equal.value:
                        condition += f"{item}={query_Value}"
                    elif query_method == QueryMethod.GreaterThan.value:
                        condition += f"{item}>{query_Value}"
                    elif query_method == QueryMethod.GreaterThanOrEqual.value:
                        condition += f"{item}>={query_Value}"
                    elif query_method == QueryMethod.LessThan.value:
                        condition += f"{item}<{query_Value}"
                    elif query_method == QueryMethod.LessThanOrEqual.value:
                        condition += f"{item}<={query_Value}"
                    elif query_method == QueryMethod.NotEqual.value:
                        condition += f"{item}<>{query_Value}"
                if query_type == "Sort" and query_Value != "":
                    order = f"{item} {query_Value}"

        return condition, order

    def get_system_user_table(self):
        """
        :description: 获取系统用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        user_dict = UserInfoModel(
            self.get_manage_context_key()).get_dict_list()
        return user_dict

    def logout(self, user_id):
        """
        :description: 用户退出
        :param user_id：用户id
        :return: 
        :last_editors: HuangJingCan
        """
        if user_id.strip() == "":
            return
        if config.get_value("login_type") == "redis":
            self.redis_init().hdel(
                config.get_value("redis_provider_name_user_login"), user_id)
        else:
            UserLoginModel(config.get_value("manage_context_key")).del_entity(
                "UserID=%s", user_id)
        self.clear_cookie("UserID")
        self.clear_cookie("UserIDMD5")
        self.clear_cookie("UserToken")

    def check_power_menu(self, api_path, cote_id):
        """
        :description: 权限判断
        :param api_path：路径
        :param cote_id：权限码值
        :return: True or False
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        menu_info_list = MenuInfoModel(manage_context_key).get_list(
            f"ApiPath LIKE '%{api_path}%'")
        if not menu_info_list:
            return False
        if len([i for i in menu_info_list if i.IsPower == 0]) > 0:
            return True
        role_user_list = RoleUserModel(manage_context_key).get_list(
            "UserID=%s", params=self.request_user_id())
        role_power_list = RolePowerModelEx(
            manage_context_key).get_role_power_list(
                [i.RoleID for i in role_user_list])
        cote_list = [i for i in role_power_list if i.CoteID == cote_id]
        menu_list = [i.MenuID for i in menu_info_list]
        if len([i for i in cote_list if menu_list.__contains__(i.MenuID)]) > 0:
            return True
        return False

    def auto_mapper(self, s_model, map_dict=None):
        """
        :description: 对象映射（把map_dict值赋值到实体s_model中）
        :param s_model：需要映射的实体对象
        :param map_dict：被映射的实体字典
        :return: 映射后的实体s_model
        """
        if map_dict:
            field_list = s_model.get_field_list()
            for filed in field_list:
                if filed in map_dict:
                    setattr(s_model, filed, map_dict[filed])
        return s_model


def login_filter(is_need_login=True, optional_params=None):
    """
    :description: 登陆过滤装饰器 仅限handler使用
    :param is_need_login：是否需要登陆
    :param optional_params：其他参数
    :return: handler
    """
    def check_login(handler):
        def wrapper(self, **args):
            base_manage_context_key = config.get_value(
                "base_manage_context_key")
            # 获取头部信息
            header_token = self.request_header_token()
            user_id = header_token["UserID"] if header_token.__contains__(
                "UserID") else ""
            user_token = header_token[
                "UserToken"] if header_token.__contains__("UserToken") else ""
            user_id_md5 = header_token[
                "UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
            if user_id.strip() == "" or user_token.strip(
            ) == "" or user_id_md5.strip() == "":
                return self.reponse_common("NoLogin", "未登录")
            if is_need_login and CryptoHelper.md5_encrypt(
                    user_id,
                    config.get_value("login_encrypt_key")) != user_id_md5:
                return self.reponse_common("NoLogin", "未登录")

            # 登陆日志判断，Redis还是MySQL
            if config.get_value("login_type") == "redis":
                redis_user_login = self.redis_init().hget(
                    config.get_value("redis_provider_name_user_login"),
                    user_id)
                user_login = {}
                if redis_user_login:
                    user_login = json.loads(redis_user_login)

                if not user_login or TimeHelper.format_time_to_datetime(
                        user_login["ExpireTime"]
                ) < TimeHelper.get_now_datetime():
                    if not is_need_login:
                        return
                    return self.reponse_common("UserExpire", "用户已过期，请重新登录")
                if user_login["UserToken"] != user_token:
                    if not is_need_login:
                        return
                    return self.reponse_common("DeviceExpire", "用户在其他终端登录")

                curr_user_info = UserInfoModel(
                    config.get_value("manage_context_key")).get_entity_by_id(
                        user_id)
                if curr_user_info.IsLock == 1:
                    return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")

                user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(
                    hour=config.get_value("login_expire"))
                self.redis_init().hset(
                    config.get_value("redis_provider_name_user_login"),
                    user_id, self.json_dumps(user_login))
            else:
                user_login_model = UserLoginModel(base_manage_context_key)
                user_login = user_login_model.get_entity_by_id(user_id)

                if not user_login or TimeHelper.format_time_to_datetime(
                        user_login.ExpireTime) < TimeHelper.get_now_datetime():
                    if not is_need_login:
                        return
                    return self.reponse_common("UserExpire", "用户已过期，请重新登录")
                if user_login.UserToken != user_token:
                    if not is_need_login:
                        return
                    return self.reponse_common("DeviceExpire", "用户在其他终端登录")

                manage_context_key = self.get_manage_context_key()

                curr_user_info = UserInfoModel(
                    manage_context_key).get_entity_by_id(user_id)
                if not curr_user_info:
                    return self.reponse_common("UserNoExist", "用户不存在，请重新登录")
                if curr_user_info.IsLock == 1:
                    return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")

                if base_manage_context_key != manage_context_key:
                    curr_user_info = UserInfoModel(
                        base_manage_context_key).get_entity_by_id(user_id)
                    if not curr_user_info:
                        return self.reponse_common("UserNoExist",
                                                   "用户不存在，请重新登录")
                    if curr_user_info.IsLock == 1:
                        return self.reponse_common("UserLimit", "用户已被锁，请联系管理员")

                user_login.ExpireTime = TimeHelper.add_hours_by_format_time(
                    hour=config.get_value("login_expire"))
                user_login_model.update_table(
                    f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s",
                    user_login.UserID)

            return handler(self, **args)

        return wrapper

    return check_login


def power_filter(is_check_power=True, optional_params=None):
    """ 
    权限过滤装饰器 仅限handler使用 
    """
    def check_power(handler):
        def wrapper(self, **args):
            user_info = self.get_curr_user_info()
            base_user_info = self.get_base_user_info()
            if user_info and base_user_info:
                if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
                    api_path = self.request.uri
                    if api_path.strip() == "":
                        return self.reponse_common("NoPower", "没有权限")
                    page_id = self.request_manage_page_id()
                    cote_id = page_id.split("$")[1] if page_id.__contains__(
                        "$") else ""
                    if not self.check_power_menu(api_path, cote_id):
                        return self.reponse_common("NoPower", "没有权限")

            return handler(self, **args)

        return wrapper

    return check_power



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileRestrictPicModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileRestrictPicModel, self).__init__(FileRestrictPic, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileRestrictPic:

    def __init__(self):
        super(FileRestrictPic, self).__init__()
        self.SystemFilePicID = ""  # 文件系统图片标识
        self.FileRestrictID = ""  # 存储路经标识
        self.SortIndex = 0  # 创建排序号
        self.IsCreateWaterMark = 0  # 是否创建水印
        self.WatermarkText = ""  # 水印文字
        self.HorizontalAlign = 0  # 水平位置
        self.VerticalAlign = 0  # 垂直位置
        self.ImageWidth = 0  # 图片宽度
        self.ImageHeight = 0  # 图片高度
        self.WatermarkType = 0  # 水印类型
        self.WaterImageID = ""  # 水印图标

    @classmethod
    def get_field_list(self):
        return ['SystemFilePicID', 'FileRestrictID', 'SortIndex', 'IsCreateWaterMark', 'WatermarkText', 'HorizontalAlign', 'VerticalAlign', 'ImageWidth', 'ImageHeight', 'WatermarkType', 'WaterImageID']
        
    @classmethod
    def get_primary_key(self):
        return "SystemFilePicID"

    def __str__(self):
        return "cms_filerestrictpic_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2020-12-08 15:48:09
:LastEditors: ChenXiaolei
:Description: 栏目扩展类
"""

from seven_framework.uuid import *
from seven_studio.utils.dict import *

from seven_studio.models.db_models.menu.menu_info_model import *
from seven_studio.models.enum import ButtonType
from seven_studio.models.enum import ButtonPlace


class MenuInfoDto():
    """
    :description: 自定义实体(栏目)
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def __init__(self):
        self.MenuID = ""
        self.MenuIcon = ""
        self.MenuName = ""
        self.ParentID = ""
        self.IsShow = 0
        self.IsPower = 0
        self.IDPath = ""
        self.ShowCondition = ""
        self.CommandParms = ""
        self.ButtonColor = ""
        self.MenuCoteID = 0
        self.MenuCoteKey = ""
        self.ChildList = []
        self.MenuNamePath = ""
        self.ApiPath = ""
        self.ViewPath = ""
        self.ButtonPlace = 0
        self.CommandName = ""
        self.ActionType = 0
        self.ActionRender = 0
        self.MenuType = 0
        self.SortIndex = 0

    @classmethod
    def get_field_list(self):
        return [
            'MenuID', 'MenuIcon', 'MenuName', 'ParentID', 'IsShow', 'IsPower',
            'IDPath', 'ShowCondition', 'CommandParms', 'ButtonColor',
            'MenuCoteID', 'MenuCoteKey', 'ChildList', 'MenuNamePath',
            'ApiPath', 'ViewPath', 'ButtonPlace', 'CommandName', 'ActionType',
            'ActionRender', 'MenuType', 'SortIndex'
        ]


class MenuInfoEx(MenuInfo):
    def get_list_by_menu_list(self, menu_info_list):
        for menu_info in menu_info_list:
            menu_info = self.get_entity_by_menu_info(menu_info)
        return menu_info_list

    def get_entity_by_menu_info(self, menu_info):
        menu_info.MenuChildID = menu_info.MenuID + ":Child"
        menu_info.ApiPathValue = "/" + menu_info.MenuID + menu_info.ApiPath

        view_path_find_index = menu_info.ViewPath.find("/:")
        if view_path_find_index > 0:
            menu_info.ViewPathValue = menu_info.ViewPath[
                0:view_path_find_index]
        else:
            menu_info.ViewPathValue = menu_info.ViewPath

        menu_cote_key = "$" + menu_info.MenuCoteKey if menu_info.MenuCoteKey.strip(
        ) != "" else ""

        menu_info.RedirctPathValue = f"/{menu_info.MenuID}{menu_cote_key}{menu_info.ViewPathValue.lower()}"

        if menu_info.ViewPath.strip() != "":
            menu_info.RoutePathValue = f"/{menu_info.MenuID}{menu_cote_key}{menu_info.ViewPath.lower()}"
        else:
            menu_info.RoutePathValue = ""

        return menu_info


class MenuInfoModelEx(MenuInfoModel):
    """
    :description: 菜单扩展类
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def add_fast_menu(self, parent_id, suffix_name, button_type_str):
        """
        :description: 快速添加菜单
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        button_type_list = button_type_str.split(",")
        for button_Type in button_type_list:
            curr_button_type_enum = int(button_Type)
            curr_menu_info = MenuInfo()
            curr_menu_info.ButtonColor = "primary"
            curr_menu_info.ParentID = parent_id
            curr_menu_info.MenuType = 3
            curr_menu_info.IsShow = 1
            curr_menu_info.IsPower = 1
            if curr_button_type_enum == ButtonType.Add.value:
                curr_menu_info.ButtonPlace = ButtonPlace.Top.value
                curr_menu_info.CommandName = "create"
                curr_menu_info.MenuName = "新增"
                curr_menu_info.MenuIcon = "plus-circle"
            elif curr_button_type_enum == ButtonPlace.List.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "delete"
                curr_menu_info.MenuName = "删除"
                curr_menu_info.MenuIcon = "trash-o"
                curr_menu_info.ButtonColor = "danger"
            elif curr_button_type_enum == ButtonType.Modify.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "edit"
                curr_menu_info.MenuName = "修改"
                curr_menu_info.MenuIcon = "edit"
            elif curr_button_type_enum == ButtonType.Save.value:
                curr_menu_info.ButtonPlace = ButtonPlace.Top.value
                curr_menu_info.CommandName = "save"
                curr_menu_info.MenuName = "保存"
                curr_menu_info.MenuIcon = "save"
            elif curr_button_type_enum == ButtonType.Search.value:
                curr_menu_info.ButtonPlace = ButtonPlace.Top.value
                curr_menu_info.CommandName = "search"
                curr_menu_info.MenuName = "查询"
                curr_menu_info.MenuIcon = "search"
            elif curr_button_type_enum == ButtonType.View.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "view"
                curr_menu_info.MenuName = "查看详细"
                curr_menu_info.ButtonColor = "info"
            elif curr_button_type_enum == ButtonType.Release.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "release"
                curr_menu_info.MenuName = "发布"
            elif curr_button_type_enum == ButtonType.UnRelease.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "unRelease"
                curr_menu_info.MenuName = "取消发布"
                curr_menu_info.ButtonColor = "info"
            elif curr_button_type_enum == ButtonType.Back.value:
                curr_menu_info.ButtonPlace = ButtonPlace.List.value
                curr_menu_info.CommandName = "back"
                curr_menu_info.MenuName = "返回"

            if curr_button_type_enum != ButtonType.Search.value:
                curr_menu_info.MenuName += suffix_name

            self.add(curr_menu_info)

    def add(self, menu_info):
        """
        :description: 添加方法
        :param menu_info：菜单实体
        :return: 
        :last_editors: HuangJingCan
        """
        menu_info.MenuID = UUIDHelper.get_uuid()
        self.add_entity(menu_info)
        parent_power_menu = self.get_entity_by_id(menu_info.ParentID)

        if parent_power_menu:
            parent_power_menu.HaveChild = 1
            self.update(parent_power_menu)
            menu_info.IDPath = "," + parent_power_menu.IDPath.strip(
                ",") + "," + menu_info.MenuID + ","
            menu_info.MenuNamePath = parent_power_menu.MenuNamePath + "," + menu_info.MenuName
            menu_info.Depth = parent_power_menu.Depth + 1
            menu_info.SortIndex = int(
                self.get_total("ParentID=%s", params=menu_info.ParentID))

        else:
            menu_info.MenuType = 1
            menu_info.IDPath = menu_info.ParentID + "," + menu_info.MenuID + ","
            menu_info.Depth = 1
            menu_info.SortIndex = int(
                self.get_total("ParentID=%s", params=[menu_info.ParentID]))

        self.update(menu_info)

        return menu_info.MenuID

    def add_menu(self, menu_info):
        """
        :description: 添加菜单
        :param menu_info：菜单实体
        :return: 
        :last_editors: HuangJingCan
        """
        self.add(menu_info)
        return DictUtil.auto_mapper(MenuInfoDto(), menu_info.__dict__)

    def update(self, menu_info):
        """
        :description: 更新菜单
        :param menu_info：菜单实体
        :return: 
        :last_editors: HuangJingCan
        """
        if menu_info.MenuNamePath != "":
            menu_name_list = [
                i for i in menu_info.MenuNamePath.strip(",").split(",")
                if i != ""
            ]
            menu_name_list.pop()
            if menu_name_list:
                menu_info.MenuNamePath = "," + ','.join(
                    menu_name_list) + "," + menu_info.MenuName + ","
        menu_info.MenuNamePath = "," + menu_info.MenuName + "," if menu_info.MenuNamePath == "" else menu_info.MenuNamePath

        return self.update_entity(menu_info)

    def update_menu(self, menu_info):
        """
        :description: 更新菜单
        :param menu_info：菜单实体
        :return: 
        :last_editors: HuangJingCan
        """
        self.update(menu_info)
        return DictUtil.auto_mapper(MenuInfoDto(), menu_info.__dict__)

    def add_copy_menu(self, copy_menu_id, stick_menu_id):
        """
        :description: 粘贴菜单
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        menu_info_list = self.get_list(f"IDPath LIKE '%{copy_menu_id}%'")
        if menu_info_list:
            copy_menu_info = [
                i for i in menu_info_list if i.MenuID == copy_menu_id
            ][0]
            copy_menu_info.MenuType = 2 if copy_menu_info.MenuType == 1 else copy_menu_info.MenuType
            copy_menu_info.MenuID = UUIDHelper.get_uuid()
            copy_menu_info.MenuName += "==复制"
            copy_menu_info.ParentID = stick_menu_id
            copy_menu_info.SortIndex = 0
            self.add(copy_menu_info)
            self.add_copy_child_menu(copy_menu_id, copy_menu_info.MenuID,
                                     menu_info_list)

    def add_copy_child_menu(self, old_parent_id, curr_parent_id,
                            menu_info_list):
        """
        :description: 粘贴子节点
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        curr_menu_info_list = [
            i for i in menu_info_list if i.ParentID == old_parent_id
        ]
        for curr_menu_info in curr_menu_info_list:
            curr_menu_id = curr_menu_info.MenuID
            curr_menu_info.MenuID = UUIDHelper.get_uuid()
            curr_menu_info.ParentID = curr_parent_id
            curr_menu_info.SortIndex = 0
            self.add(curr_menu_info)
            self.add_copy_child_menu(
                curr_menu_id, curr_menu_info.MenuID,
                [i for i in menu_info_list if i.ParentID == old_parent_id])

    def update_move(self, move_id, target_id):
        """
        :description: 移动菜单
        :param move_id：被移动的菜单id
        :param target_id：目的地菜单id
        :return: 
        :last_editors: HuangJingCan
        """
        move_menu_info = self.get_entity_by_id(move_id)
        if not move_menu_info or move_menu_info.ParentID == target_id or move_id == target_id:
            return

        old_parent_id = move_menu_info.ParentID
        id_path = move_menu_info.IDPath
        menu_name_path = move_menu_info.MenuNamePath
        depth = move_menu_info.Depth
        menu_info_list = self.get_list(f"IDPath LIKE '{id_path}%'")
        target_menu_info = self.get_entity_by_id(target_id)
        update_id_path = target_id + "," + move_id if not target_menu_info else target_menu_info.IDPath + move_id + ","
        update_name_path = "," + move_menu_info.MenuName if not target_menu_info else target_menu_info.MenuNamePath + move_menu_info.MenuName + ","
        update_depth = 1 if not target_menu_info else target_menu_info.Depth

        for power_menu in menu_info_list:
            power_menu.MenuNamePath = power_menu.MenuNamePath.replace(
                menu_name_path, update_name_path)
            power_menu.IDPath = power_menu.IDPath.replace(
                id_path, update_id_path)
            power_menu.Depth = power_menu.Depth - depth + 1 + update_depth
            if power_menu.MenuID == move_id:
                power_menu.ParentID = target_id
            self.update_entity(power_menu)

        self.update_table("HaveChild=1", "MenuID=%s", target_id)

        dict_total = self.get_total("ParentID=%s", params=old_parent_id)
        have_child = 0
        if dict_total and int(dict_total) > 0:
            have_child = 1
        self.update_table("HaveChild=%s", "MenuID=%s", [have_child, target_id])

    def update_after_before_move(self,
                                 move_id,
                                 target_id,
                                 top_field_name,
                                 condition="",
                                 is_after=True):
        """
        :description: 移动
        :param move_id：被移动的菜单id
        :param target_id：目的地菜单id
        :param top_field_name：排序字段名称
        :param condition：查询条件
        :param is_after：after是True，before是False
        :return: 
        :last_editors: HuangJingCan
        """
        move_menu_info = self.get_entity_by_id(move_id)
        target_menu_info = self.get_entity_by_id(target_id)
        if not move_menu_info or not target_menu_info:
            return
        if move_menu_info.ParentID != target_menu_info.ParentID:
            self.update_move(move_id, target_menu_info.ParentID)

        self.move_record(move_id, target_id, top_field_name, condition,
                         is_after)

    def move_record(self,
                    select_id,
                    target_id,
                    top_field_name,
                    condition="",
                    is_after=True):
        """
        :description: 向前或者向后移动菜单（通用方法，可移动到base_model）
        :param select_id：被移动的菜单id
        :param target_id：目的地菜单id
        :param top_field_name：排序字段名称
        :param condition：查询条件
        :param is_after：after是True，before是False
        :return: 执行行数
        :last_editors: HuangJingCan
        """
        reverse = False
        select_sort_id = 0
        primary_key = MenuInfo().get_primary_key()
        table_name = MenuInfo().__str__()
        dict_select_sort_id = self.get_dict(f"{primary_key}=%s",
                                            field=top_field_name,
                                            params=select_id)
        if dict_select_sort_id:
            select_sort_id = int(dict_select_sort_id[top_field_name])

        target_sort_id = 0
        dict_target_sort_id = self.get_dict(f"{primary_key}=%s",
                                            field=top_field_name,
                                            params=target_id)
        if dict_target_sort_id:
            target_sort_id = int(dict_target_sort_id[top_field_name])

        condition = "" if condition == "" else condition + " AND "
        if is_after:
            condition += f"{top_field_name}>{select_sort_id} AND {top_field_name}<={target_sort_id} ORDER BY {top_field_name}"
        else:
            reverse = True
            condition += f"{top_field_name}>={target_sort_id} AND {top_field_name}<{select_sort_id} ORDER BY {top_field_name}"
        dict_list = self.get_dict_list(condition)
        sort_info_list = self.get_sort_list(dict_list, top_field_name)

        if isinstance(select_id, int):
            sql = f"UPDATE {table_name} SET {top_field_name}={target_sort_id} WHERE {primary_key}={select_id};"
        else:
            sql = f"UPDATE {table_name} SET {top_field_name}={target_sort_id} WHERE {primary_key}='{select_id}';"
        sort_value = select_sort_id
        sort_info_list.sort(key=lambda x: x["sort_value"], reverse=reverse)
        for sort_info in sort_info_list:
            sort_id = sort_info["id"]
            if isinstance(select_id, int):
                sql += f"UPDATE {table_name} SET {top_field_name}={sort_value} WHERE {primary_key}={sort_id};"
            else:
                sql += f"UPDATE {table_name} SET {top_field_name}={sort_value} WHERE {primary_key}='{sort_id}';"
            sort_value = sort_info["sort_value"]

        sql_list = [i for i in sql.split(";") if i != ""]

        return self.transaction_execute(sql_list)

    def get_sort_list(self, dict_list, top_field_name):
        """
        :description: 列表加工后返回id和sort的列表
        :param dict_list：
        :param top_field_name：
        :return: 字典列表
        :last_editors: HuangJingCan
        """
        obj_list = []
        top_field_name = top_field_name.replace("`", "")
        primary_key = MenuInfo().get_primary_key()
        for dr in dict_list:
            sort_info = {}
            if dr[primary_key] != "":
                sort_info["id"] = dr[primary_key]
            if dr[top_field_name] != "":
                sort_info["sort_value"] = int(dr[top_field_name])
            obj_list.append(sort_info)
        return obj_list
